==> nomachine-7.8.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/NXSession.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXSession::BEGIN{package NXSession;no warnings;require Common::Logger;do{
"\x43\x6f\x6d\x6d\x6f\x6e\x3a\x3a\x4c\x6f\x67\x67\x65\x72"->import};}package 
NXSession;no warnings;($playerConnected="\x6e\x6f\x74\x53\x65\x74");(
$__sessionType=(""));$__ref_parameters;($sessionCloseStarted=
(0x071d+ 4757-0x19b2));sub playerConnectedThroughNXD{Logger::debug (
"\x4e\x58\x53\x65\x73\x73\x69\x6f\x6e\x3a\x3a\x70\x6c\x61\x79\x65\x72\x43\x6f\x6e\x6e\x65\x63\x74\x65\x64\x54\x68\x72\x6f\x75\x67\x68\x4e\x58\x44"
);($playerConnected="\x6e\x78\x64");}sub playerConnectedThroughSSHD{
Logger::debug (
"\x4e\x58\x53\x65\x73\x73\x69\x6f\x6e\x3a\x3a\x70\x6c\x61\x79\x65\x72\x43\x6f\x6e\x6e\x65\x63\x74\x65\x64\x54\x68\x72\x6f\x75\x67\x68\x53\x53\x48\x44"
);($playerConnected="\x73\x73\x68\x64");}sub playerIsConnected{if ((
$playerConnected eq "\x6e\x6f\x74\x53\x65\x74")){Logger::debug (
"\x4e\x58\x53\x65\x73\x73\x69\x6f\x6e\x3a\x3a\x70\x6c\x61\x79\x65\x72\x49\x73\x43\x6f\x6e\x6e\x65\x63\x74\x65\x64\x20\x30"
);return ((0x08d6+ 5878-0x1fcc));}Logger::debug (
"\x4e\x58\x53\x65\x73\x73\x69\x6f\x6e\x3a\x3a\x70\x6c\x61\x79\x65\x72\x49\x73\x43\x6f\x6e\x6e\x65\x63\x74\x65\x64\x20\x31"
);return ((0x0856+ 6257-0x20c6));}sub playerIsConnectedThroughNXD{if ((
$playerConnected eq "\x6e\x78\x64")){Logger::debug (
"\x4e\x58\x53\x65\x73\x73\x69\x6f\x6e\x3a\x3a\x70\x6c\x61\x79\x65\x72\x49\x73\x43\x6f\x6e\x6e\x65\x63\x74\x65\x64\x54\x68\x72\x6f\x75\x67\x68\x4e\x58\x44\x20\x31"
);return ((0x07e2+ 178-0x0893));}Logger::debug (
"\x4e\x58\x53\x65\x73\x73\x69\x6f\x6e\x3a\x3a\x70\x6c\x61\x79\x65\x72\x49\x73\x43\x6f\x6e\x6e\x65\x63\x74\x65\x64\x54\x68\x72\x6f\x75\x67\x68\x4e\x58\x44\x20\x30"
);return ((0x19a0+ 3048-0x2588));}sub playerIsConnectedThroughSSHD{if ((
$playerConnected eq "\x73\x73\x68\x64")){Logger::debug (
"\x4e\x58\x53\x65\x73\x73\x69\x6f\x6e\x3a\x3a\x70\x6c\x61\x79\x65\x72\x49\x73\x43\x6f\x6e\x6e\x65\x63\x74\x65\x64\x54\x68\x72\x6f\x75\x67\x68\x53\x53\x48\x44\x20\x31"
);return ((0x165b+ 2767-0x2129));}Logger::debug (
"\x4e\x58\x53\x65\x73\x73\x69\x6f\x6e\x3a\x3a\x70\x6c\x61\x79\x65\x72\x49\x73\x43\x6f\x6e\x6e\x65\x63\x74\x65\x64\x54\x68\x72\x6f\x75\x67\x68\x53\x53\x48\x44\x20\x30"
);return ((0x1db8+ 2087-0x25df));}sub addConnectionVariableToEnvironmentArray{(my $ref_array
=shift (@_));(my $nxConnectionEnv=libnxh::NXTransGetEnvironment (
"\x4e\x58\x5f\x43\x4f\x4e\x4e\x45\x43\x54\x49\x4f\x4e"));if (($nxConnectionEnv 
ne (""))){push (@$ref_array,"\x73\x65\x74\x20\x65\x6e\x76",(
"\x4e\x58\x5f\x43\x4f\x4e\x4e\x45\x43\x54\x49\x4f\x4e\x3d".$nxConnectionEnv));
Logger::debug (
"\x4e\x58\x53\x65\x73\x73\x69\x6f\x6e\x3a\x3a\x61\x64\x64\x43\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x56\x61\x72\x69\x61\x62\x6c\x65\x54\x6f\x45\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x41\x72\x72\x61\x79\x20\x73\x65\x74\x20\x4e\x58\x5f\x43\x4f\x4e\x4e\x45\x43\x54\x49\x4f\x4e"
);}else{(my $sshConnectionEnv=libnxh::NXTransGetEnvironment (
"\x53\x53\x48\x5f\x43\x4f\x4e\x4e\x45\x43\x54\x49\x4f\x4e"));if ((
$sshConnectionEnv ne (""))){push (@$ref_array,"\x73\x65\x74\x20\x65\x6e\x76",(
"\x53\x53\x48\x5f\x43\x4f\x4e\x4e\x45\x43\x54\x49\x4f\x4e\x3d".$sshConnectionEnv
));Logger::debug (
"\x4e\x58\x53\x65\x73\x73\x69\x6f\x6e\x3a\x3a\x61\x64\x64\x43\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x56\x61\x72\x69\x61\x62\x6c\x65\x54\x6f\x45\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x41\x72\x72\x61\x79\x20\x73\x65\x74\x20\x53\x53\x48\x5f\x43\x4f\x4e\x4e\x45\x43\x54\x49\x4f\x4e"
);}(my $sshClientEnv=libnxh::NXTransGetEnvironment (
"\x53\x53\x48\x5f\x43\x4c\x49\x45\x4e\x54"));if (($sshClientEnv ne (""))){push (
@$ref_array,"\x73\x65\x74\x20\x65\x6e\x76",(
"\x53\x53\x48\x5f\x43\x4c\x49\x45\x4e\x54\x3d".$sshClientEnv));Logger::debug (
"\x4e\x58\x53\x65\x73\x73\x69\x6f\x6e\x3a\x3a\x61\x64\x64\x43\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x56\x61\x72\x69\x61\x62\x6c\x65\x54\x6f\x45\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x41\x72\x72\x61\x79\x20\x73\x65\x74\x20\x53\x53\x48\x5f\x43\x4c\x49\x45\x4e\x54"
);}}}sub setSessionType{(my $sessionType=shift (@_));($__sessionType=
$sessionType);}sub getSessionType{return ($__sessionType);}sub 
setParametersReference{(my $ref_parameters=shift (@_));($__ref_parameters=
$ref_parameters);}sub getParametersReference{return ($__ref_parameters);}sub 
isRestoreSession{if (($GLOBAL::parameters{
"\x72\x65\x73\x74\x6f\x72\x65\x73\x65\x73\x73\x69\x6f\x6e"}eq "\x31")){return (
(0x1f49+ 1521-0x2539));}return ((0x0084+ 5231-0x14f3));}sub isNotRestoreSession{
return ((!isRestoreSession ()));}sub isFirstAttach{if (($GLOBAL::parameters{
"\x66\x69\x72\x73\x74\x41\x74\x74\x61\x63\x68"}eq "\x31")){return (
(0x0556+ 7287-0x21cc));}return ((0x15a6+ 2863-0x20d5));}sub isNotFirstAttach{
return ((!isFirstAttach ()));}sub considerBeforeSessionStart{if ((
isNotRestoreSession ()and isNotFirstAttach ())){NXEvent::beforeSessionStart ();}
}sub considerAfterSessionStart{if ((isNotRestoreSession ()and isNotFirstAttach 
())){NXEvent::afterSessionStart ();}}sub considerBeforeSessionClose{if (((
isNotSessionCloseStarted ()and getSessionType ())and (
Common::NXSessionType::isVirtual (getSessionType ())||
Common::NXSessionType::isAttach (getSessionType ())))){if ((isNotRestoreSession 
()and isNotFirstAttach ())){NXEvent::beforeSessionClose ();}}}sub 
considerAfterSessionClose{if ((getSessionType ()and (
Common::NXSessionType::isVirtual (getSessionType ())||
Common::NXSessionType::isAttach (getSessionType ())))){if ((isNotRestoreSession 
()and isNotFirstAttach ())){NXEvent::afterSessionClose ();}}}sub 
considerAfterSessionFailure{if (((getSessionType ()and 
Common::NXSessionType::isVirtual (getSessionType ()))or 
Common::NXSessionType::isAttach (getSessionType ()))){if ((isNotRestoreSession 
()and isNotFirstAttach ())){NXEvent::afterSessionFailure ();}}}sub 
considerAfterLocalSessionClose{if (Common::NXSessionType::isPhysical (
getSessionType ())){NXEvent::afterLocalSessionClose ();}}sub 
considerAfterLocalSessionFailure{if (Common::NXSessionType::isPhysical (
getSessionType ())){NXEvent::afterLocalSessionFailure ();}}sub 
setSessionCloseStarted{($sessionCloseStarted=(0x196c+ 950-0x1d21));}sub 
isSessionCloseStarted{return ($sessionCloseStarted);}sub 
isNotSessionCloseStarted{return ((!isSessionCloseStarted ()));}return (
(0x1106+ 3326-0x1e03));

==> nomachine-7.9.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/NXSession.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXSession::BEGIN{package NXSession;no warnings;require Common::Logger;do{
"\x43\x6f\x6d\x6d\x6f\x6e\x3a\x3a\x4c\x6f\x67\x67\x65\x72"->import};}package 
NXSession;no warnings;($playerConnected="\x6e\x6f\x74\x53\x65\x74");(
$__sessionType=(""));$__ref_parameters;($sessionCloseStarted=
(0x1258+ 1950-0x19f6));sub playerConnectedThroughNXD{Logger::debug (
"\x4e\x58\x53\x65\x73\x73\x69\x6f\x6e\x3a\x3a\x70\x6c\x61\x79\x65\x72\x43\x6f\x6e\x6e\x65\x63\x74\x65\x64\x54\x68\x72\x6f\x75\x67\x68\x4e\x58\x44"
);($playerConnected="\x6e\x78\x64");}sub playerConnectedThroughSSHD{
Logger::debug (
"\x4e\x58\x53\x65\x73\x73\x69\x6f\x6e\x3a\x3a\x70\x6c\x61\x79\x65\x72\x43\x6f\x6e\x6e\x65\x63\x74\x65\x64\x54\x68\x72\x6f\x75\x67\x68\x53\x53\x48\x44"
);($playerConnected="\x73\x73\x68\x64");}sub playerIsConnected{if ((
$playerConnected eq "\x6e\x6f\x74\x53\x65\x74")){Logger::debug (
"\x4e\x58\x53\x65\x73\x73\x69\x6f\x6e\x3a\x3a\x70\x6c\x61\x79\x65\x72\x49\x73\x43\x6f\x6e\x6e\x65\x63\x74\x65\x64\x20\x30"
);return ((0x01e1+ 3359-0x0f00));}Logger::debug (
"\x4e\x58\x53\x65\x73\x73\x69\x6f\x6e\x3a\x3a\x70\x6c\x61\x79\x65\x72\x49\x73\x43\x6f\x6e\x6e\x65\x63\x74\x65\x64\x20\x31"
);return ((0x1326+ 1083-0x1760));}sub playerIsConnectedThroughNXD{if ((
$playerConnected eq "\x6e\x78\x64")){Logger::debug (
"\x4e\x58\x53\x65\x73\x73\x69\x6f\x6e\x3a\x3a\x70\x6c\x61\x79\x65\x72\x49\x73\x43\x6f\x6e\x6e\x65\x63\x74\x65\x64\x54\x68\x72\x6f\x75\x67\x68\x4e\x58\x44\x20\x31"
);return ((0x051f+ 6825-0x1fc7));}Logger::debug (
"\x4e\x58\x53\x65\x73\x73\x69\x6f\x6e\x3a\x3a\x70\x6c\x61\x79\x65\x72\x49\x73\x43\x6f\x6e\x6e\x65\x63\x74\x65\x64\x54\x68\x72\x6f\x75\x67\x68\x4e\x58\x44\x20\x30"
);return ((0x0b51+ 5865-0x223a));}sub playerIsConnectedThroughSSHD{if ((
$playerConnected eq "\x73\x73\x68\x64")){Logger::debug (
"\x4e\x58\x53\x65\x73\x73\x69\x6f\x6e\x3a\x3a\x70\x6c\x61\x79\x65\x72\x49\x73\x43\x6f\x6e\x6e\x65\x63\x74\x65\x64\x54\x68\x72\x6f\x75\x67\x68\x53\x53\x48\x44\x20\x31"
);return ((0x022c+ 8825-0x24a4));}Logger::debug (
"\x4e\x58\x53\x65\x73\x73\x69\x6f\x6e\x3a\x3a\x70\x6c\x61\x79\x65\x72\x49\x73\x43\x6f\x6e\x6e\x65\x63\x74\x65\x64\x54\x68\x72\x6f\x75\x67\x68\x53\x53\x48\x44\x20\x30"
);return ((0x08a8+ 2120-0x10f0));}sub addConnectionVariableToEnvironmentArray{(my $ref_array
=shift (@_));(my $nxConnectionEnv=libnxh::NXTransGetEnvironment (
"\x4e\x58\x5f\x43\x4f\x4e\x4e\x45\x43\x54\x49\x4f\x4e"));if (($nxConnectionEnv 
ne (""))){push (@$ref_array,"\x73\x65\x74\x20\x65\x6e\x76",(
"\x4e\x58\x5f\x43\x4f\x4e\x4e\x45\x43\x54\x49\x4f\x4e\x3d".$nxConnectionEnv));
Logger::debug (
"\x4e\x58\x53\x65\x73\x73\x69\x6f\x6e\x3a\x3a\x61\x64\x64\x43\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x56\x61\x72\x69\x61\x62\x6c\x65\x54\x6f\x45\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x41\x72\x72\x61\x79\x20\x73\x65\x74\x20\x4e\x58\x5f\x43\x4f\x4e\x4e\x45\x43\x54\x49\x4f\x4e"
);}else{(my $sshConnectionEnv=libnxh::NXTransGetEnvironment (
"\x53\x53\x48\x5f\x43\x4f\x4e\x4e\x45\x43\x54\x49\x4f\x4e"));if ((
$sshConnectionEnv ne (""))){push (@$ref_array,"\x73\x65\x74\x20\x65\x6e\x76",(
"\x53\x53\x48\x5f\x43\x4f\x4e\x4e\x45\x43\x54\x49\x4f\x4e\x3d".$sshConnectionEnv
));Logger::debug (
"\x4e\x58\x53\x65\x73\x73\x69\x6f\x6e\x3a\x3a\x61\x64\x64\x43\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x56\x61\x72\x69\x61\x62\x6c\x65\x54\x6f\x45\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x41\x72\x72\x61\x79\x20\x73\x65\x74\x20\x53\x53\x48\x5f\x43\x4f\x4e\x4e\x45\x43\x54\x49\x4f\x4e"
);}(my $sshClientEnv=libnxh::NXTransGetEnvironment (
"\x53\x53\x48\x5f\x43\x4c\x49\x45\x4e\x54"));if (($sshClientEnv ne (""))){push (
@$ref_array,"\x73\x65\x74\x20\x65\x6e\x76",(
"\x53\x53\x48\x5f\x43\x4c\x49\x45\x4e\x54\x3d".$sshClientEnv));Logger::debug (
"\x4e\x58\x53\x65\x73\x73\x69\x6f\x6e\x3a\x3a\x61\x64\x64\x43\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x56\x61\x72\x69\x61\x62\x6c\x65\x54\x6f\x45\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x41\x72\x72\x61\x79\x20\x73\x65\x74\x20\x53\x53\x48\x5f\x43\x4c\x49\x45\x4e\x54"
);}}}sub setSessionType{(my $sessionType=shift (@_));($__sessionType=
$sessionType);}sub getSessionType{return ($__sessionType);}sub 
setParametersReference{(my $ref_parameters=shift (@_));($__ref_parameters=
$ref_parameters);}sub getParametersReference{return ($__ref_parameters);}sub 
isRestoreSession{if (($GLOBAL::parameters{
"\x72\x65\x73\x74\x6f\x72\x65\x73\x65\x73\x73\x69\x6f\x6e"}eq "\x31")){return (
(0x0459+ 1708-0x0b04));}return ((0x15ad+ 3819-0x2498));}sub isNotRestoreSession{
return ((!isRestoreSession ()));}sub isFirstAttach{if (($GLOBAL::parameters{
"\x66\x69\x72\x73\x74\x41\x74\x74\x61\x63\x68"}eq "\x31")){return (
(0x2136+  22-0x214b));}return ((0x01b1+ 2732-0x0c5d));}sub isNotFirstAttach{
return ((!isFirstAttach ()));}sub considerBeforeSessionStart{if ((
isNotRestoreSession ()and isNotFirstAttach ())){NXEvent::beforeSessionStart ();}
}sub considerAfterSessionStart{if ((isNotRestoreSession ()and isNotFirstAttach 
())){NXEvent::afterSessionStart ();}}sub considerBeforeSessionClose{if (((
isNotSessionCloseStarted ()and getSessionType ())and (
Common::NXSessionType::isVirtual (getSessionType ())||
Common::NXSessionType::isAttach (getSessionType ())))){if ((isNotRestoreSession 
()and isNotFirstAttach ())){NXEvent::beforeSessionClose ();}}}sub 
considerAfterSessionClose{if ((getSessionType ()and (
Common::NXSessionType::isVirtual (getSessionType ())||
Common::NXSessionType::isAttach (getSessionType ())))){if ((isNotRestoreSession 
()and isNotFirstAttach ())){NXEvent::afterSessionClose ();}}}sub 
considerAfterSessionFailure{if (((getSessionType ()and 
Common::NXSessionType::isVirtual (getSessionType ()))or 
Common::NXSessionType::isAttach (getSessionType ()))){if ((isNotRestoreSession 
()and isNotFirstAttach ())){NXEvent::afterSessionFailure ();}}}sub 
considerAfterLocalSessionClose{if (Common::NXSessionType::isPhysical (
getSessionType ())){NXEvent::afterLocalSessionClose ();}}sub 
considerAfterLocalSessionFailure{if (Common::NXSessionType::isPhysical (
getSessionType ())){NXEvent::afterLocalSessionFailure ();}}sub 
setSessionCloseStarted{($sessionCloseStarted=(0x262f+ 120-0x26a6));}sub 
isSessionCloseStarted{return ($sessionCloseStarted);}sub 
isNotSessionCloseStarted{return ((!isSessionCloseStarted ()));}return (
(0x16ef+ 1228-0x1bba));
